# About
The Python Package Index Project (pypipr)


# Setup
Install with pip
```
python -m pip install pypipr
```

Test with
```python
from pypipr.pypipr import Pypipr
Pypipr.test_print()
```


# Pypipr Class
`test_print()` memastikan module sudah terinstal dan dapat dijalankan
```python
from pypipr.pypipr import Pypipr
Pypipr.test_print()
```


# iconsole
`print_colorize()` print ke console dengan warna

```python
from pypipr.iconsole import print_colorize
print_colorize("Print some text")
```


`@Log()` / `Log decorator` akan melakukan print ke console. Mempermudah pembuatan log karena tidak perlu mengubah fungsi yg sudah ada. Berguna untuk memberikan informasi proses program yg sedang berjalan.

```python
from pypipr.iconsole import log

@log("Calling some function")
def some_function():
    ...
    return
```


`print_log` akan melakukan print ke console. Berguna untuk memberikan informasi proses program yg sedang berjalan.

```python
from pypipr.iconsole import print_log
print_log("Standalone Log")
```


`input_char()` meminta masukan satu huruf tanpa menekan enter. Char tidak ditampilkan.

```python
from pypipr.iconsole import input_char
input_char("Input Char without print : ")
```


`input_char()` meminta masukan satu huruf tanpa menekan enter. Char ditampilkan.

```python
from pypipr.iconsole import input_char_echo
input_char_echo("Input Char n : ")
```


# idatetime
`datetime_now()` memudahkan dalam membuat tanggal dan waktu untuk suatu timezone

```python
from pypipr.idatetime import datetime_now
datetime_now("Asia/Jakarta")
datetime_now("GMT")
datetime_now("Etc/GMT+7")
```


# iconstant
`WINDOWS` True apabila berjalan di platform Windows

```python
from pypipr.iconstant import WINDOWS
print(WINDOWS)
```

`LINUX` True apabila berjalan di platform Linux

```python
from pypipr.iconstant import LINUX
print(LINUX)
```
